@@ -10,8 +10,14 @@ messy_adult$are50OrMore <- messy_adult$age > 50 # Add an included
 
 test_that("fastFilterVariables: ", 
           {
-			expect_equal(ncol(fastFilterVariables(messy_adult, level = 4, verbose = verbose)), 20)
-			expect_error(fastFilterVariables(messy_adult, level = "a", verbose = verbose), ": level should be 1, 2, 3 or 4.")
+            expect_equal(ncol(fastFilterVariables(messy_adult, level = 4, verbose = verbose)), 20)
+          })
+
+## is.filtering_level
+#--------------------
+test_that("Private function: is.filtering_level ", 
+          {
+            expect_error(is.filtering_level(level = "a"), ": level should be 1, 2, 3 or 4.")
           })
 
 ## fastRound
@@ -33,36 +39,31 @@ dataSet <-  data.table(numCol = c(1, 2, 3, NA),
                        charCol = c("", "a", NA, "c"), 
                        booleanCol = c(TRUE, NA, FALSE, NA))
 
-# To set NAs to 0, FALSE and "" (respectivly for numeric, boolean, character)
-data_withoutNA <- fastHandleNa(dataSet)
-
 test_that("fastHandleNa: There are no more NAs", 
           {
-            expect_equal(sum(is.na(data_withoutNA)), 0)
+            expect_false(any(is.na(fastHandleNa(dataSet))))
           })
 
 data("messy_adult")
 messy_adult$mail[sample(1:nrow(messy_adult), 10)] = NA
-messy_adult <- fastHandleNa(messy_adult)
 test_that("fastHandleNa: There are no more NAs with factor", 
           {
-            expect_equal(sum(is.na(messy_adult)), 0)
+            expect_false(any(is.na(fastHandleNa(messy_adult))))
           })
 
 ## fastIsEqual
 #--------------
 data("messy_adult")
-
-test_that("private function: fastIsEqual", 
+test_that("fastIsEqual: testing various scenariis", 
           {
-            expect_false(fastIsEqual(1:9, 1:10))
-            expect_false(fastIsEqual(messy_adult[["education"]], messy_adult[["education_num"]]))
-            expect_true(fastIsEqual(1:10, 1:10))
-            expect_true(fastIsEqual(1:1001, 1:1001))
-            expect_true(fastIsEqual(LETTERS, LETTERS))
-            expect_true(fastIsEqual(1, 1))
-            expect_false(fastIsEqual(1, 2))
-            expect_true(fastIsEqual(messy_adult, messy_adult))
+            expect_false(fastIsEqual(1:9, 1:10)) # Different legnth
+            expect_false(fastIsEqual(messy_adult[["education"]], messy_adult[["education_num"]])) # different values
+            expect_true(fastIsEqual(1:10, 1:10)) # Same vector
+            expect_true(fastIsEqual(1:1001, 1:1001)) # Same long vector
+            expect_true(fastIsEqual(LETTERS, LETTERS)) # With characters
+            expect_true(fastIsEqual(1, 1)) # Integers
+            expect_false(fastIsEqual(1, 2)) # Integers
+            expect_true(fastIsEqual(messy_adult, messy_adult)) # data.table
           })
 
 
@@ -71,7 +72,6 @@ test_that("private function: fastIsEqual",
 ## fastIsBijection
 # -----------------
 data("adult")
-
 test_that("private function: fastIsBijection", 
           {
             expect_true(fastIsBijection(adult[["education"]], adult[["education_num"]]))
@@ -88,18 +88,18 @@ test_that("private function: fastMaxNbElt",
           })
 
 
-		  
+
 ## fastIsIncluded
 # ----------------
 # data("messy_adult")
 # messy_adult$ageover50 = messy_adult$age >50
 
 # test_that("private function: fastIsBijection", 
-          # {
-            # expect_equal(fastIsIncluded(messy_adult[["constant"]], messy_adult[["date2"]]),1)
-            # expect_equal(fastIsIncluded(messy_adult[["education_num"]], messy_adult[["education"]]), "bijection")
-            # expect_equal(fastIsIncluded(messy_adult[["age"]], messy_adult[["education"]]), NULL)
-            # expect_equal(fastIsIncluded(messy_adult[["age"]], messy_adult[["ageover50"]]), 2)
-            # expect_equal(fastIsIncluded(messy_adult[["ageover50"]], messy_adult[["ageover50"]]), "bijection")
-            # expect_equal(fastIsIncluded(messy_adult[["ageover50"]], messy_adult[["age"]]), 1)
-          # })
+# {
+# expect_equal(fastIsIncluded(messy_adult[["constant"]], messy_adult[["date2"]]),1)
+# expect_equal(fastIsIncluded(messy_adult[["education_num"]], messy_adult[["education"]]), "bijection")
+# expect_equal(fastIsIncluded(messy_adult[["age"]], messy_adult[["education"]]), NULL)
+# expect_equal(fastIsIncluded(messy_adult[["age"]], messy_adult[["ageover50"]]), 2)
+# expect_equal(fastIsIncluded(messy_adult[["ageover50"]], messy_adult[["ageover50"]]), "bijection")
+# expect_equal(fastIsIncluded(messy_adult[["ageover50"]], messy_adult[["age"]]), 1)
+# })
