@@ -11,7 +11,7 @@ test_that("whichAreConstant:",
           })
 
 
-		  
+
 ## whichAreInDouble
 #------------------
 # Simple matrix
@@ -31,7 +31,7 @@ test_that("whichAreInDouble give correct RESULTS",
             expect_identical(whichAreInDouble(M1, verbose = verbose), as.integer(c(3)))
             expect_identical(whichAreInDouble(M2, verbose = verbose), as.integer(c(2)))
           })
-		  
+
 data("messy_adult")
 test_that("whichAreInDouble: exceptions", 
           {
@@ -42,55 +42,43 @@ test_that("whichAreInDouble: exceptions",
 ## whichAreBijection
 # ------------------
 data("adult")
-
-
 test_that("whichAreBijection", 
           {
             expect_equal(whichAreBijection(adult, verbose = verbose), 5)
-			expect_equal(whichAreBijection(adult, keep_cols = "education_num", verbose = verbose), 4)
-          })
-
-data("messy_adult")
-test_that("whichAreBijection: exceptions", 
-          {
-            expect_null(whichAreBijection(messy_adult[,.(date1)], verbose = verbose))
+            expect_equal(whichAreBijection(adult, keep_cols = "education_num", verbose = verbose), 4)
+            # Nothing if one column
+            expect_null(whichAreBijection(adult[,c("education"), drop = FALSE], verbose = verbose))
           })
 
 ## whichAreIncluded
 # ------------------
-
-data(messy_adult)
-
+data("messy_adult")
 # Reduce it to make it faster
 messy_adult <- messy_adult[1:5000, ]
 messy_adult$are50OrMore <- messy_adult$age > 50
 test_that("whichAreIncluded: build column", 
           {
             expect_identical(whichAreIncluded(messy_adult, verbose = verbose), as.integer(c(3, 5, 7, 13, 25)))
-			expect_identical(whichAreIncluded(messy_adult, keep_cols = "education", verbose = verbose), as.integer(c(3, 5, 7, 14, 25)))
+            expect_identical(whichAreIncluded(messy_adult, keep_cols = "education", verbose = verbose), as.integer(c(3, 5, 7, 14, 25)))
+            expect_null(whichAreIncluded(messy_adult[, .(age)], verbose = verbose))
           })
+
 # As one can, see this column that doesn't have additional info than age is spotted.
 
 # But you should be carefull, if there is a column id, every column will be dropped:
-messy_adult$id <- 1:nrow(messy_adult) # build id
-setcolorder(messy_adult, c("id", setdiff(names(messy_adult), "id"))) # Set id as first column
-test_that("whichAreIncluded: id at the beginning", 
-          {
-            expect_identical(whichAreIncluded(messy_adult, verbose = verbose), 2:26)
-          })
-
-	
-# Same but with inverse order
 rm(messy_adult)
-data(messy_adult)
+data("messy_adult")
 messy_adult$id <- 1:nrow(messy_adult) # build id
 test_that("whichAreIncluded: id at the end", 
           {
             expect_identical(whichAreIncluded(messy_adult, verbose = verbose), 1:24)
           })
-
-	
-test_that("whichAreIncluded: return NULL when no column", 
+# Set id as first column
+setcolorder(messy_adult, c("id", setdiff(names(messy_adult), "id"))) 
+test_that("whichAreIncluded: id at the beginning", 
           {
-            expect_null(whichAreIncluded(data.table(col1 = c(1, 2, 3)), verbose = TRUE))
-          })
\ No newline at end of file
+            expect_identical(whichAreIncluded(messy_adult, verbose = verbose), 2:25)
+          })
+
+
+
